``zope.dottedname``
===================

.. image:: https://pypip.in/version/zope.dottedname/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/zope.dottedname/
    :alt: Latest Version

.. image:: https://travis-ci.org/zopefoundation/zope.dottedname.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.dottedname

.. image:: https://readthedocs.org/projects/zopedottedname/badge/?version=latest
        :target: http://zopedottedname.readthedocs.org/en/latest/
        :alt: Documentation Status

Resolve strings containing dotted names into the appropriate python object.
